RESCAL
======

.. currentmodule:: pykeen.models

.. autoclass:: RESCAL
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~RESCAL.hpo_default
      ~RESCAL.regularizer_default_kwargs

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: regularizer_default_kwargs
